<?php

/**
 * @file
 * Provides helper functions for cultura_questionnaire_install().
 */

/**
 * Create the vocabulary for categorizing Question prompts (and answers).
 */
function cultura_questionnaire_create_question_types_vocabulary() {
  $description = st('Categorize question and answer sets by type of prompt.');
  $vocabulary = (object) array(
    'name' => st('Question types'),
    'description' => $description,
    'machine_name' => CULTURA_QUESTIONNAIRE_VOCABULARY,
  );
  taxonomy_vocabulary_save($vocabulary);

  // Populate the vocabulary.
  $names = array(
    st('Word Association'),
    st('Sentence Completion'),
    st('Situation Reaction'),
    st('Other Discussion Topics'),
  );

  $weight = -20;
  foreach ($names as $name) {
    $term = (object) array(
      'name' => $name,
      'vid' => $vocabulary->vid,
      'weight' => $weight,
    );
    taxonomy_term_save($term);
    $weight += 10;
    $terms[] = $term->tid;
  }

  // Save term IDs for the question types to variables for later retrieval.
  variable_set(CULTURA_QUESTIONNAIRE_WORD_ASSOCIATION, $terms[0]);
  variable_set(CULTURA_QUESTIONNAIRE_SENTENCE_COMPLETION, $terms[1]);
  variable_set(CULTURA_QUESTIONNAIRE_SITUATION_REACTION, $terms[2]);
  variable_set(CULTURA_QUESTIONNAIRE_OTHER_DISCUSSION, $terms[3]);

  return $vocabulary;
}

/**
 * Create the vocabulary for languages.
 *
 * Even though there will be only two languages for a Cultura Exchange, we do
 * the language as taxonomy for consistency with other key attributes for
 * questionnaires and answers and the content structure for the archive site.
 */
function cultura_questionnaire_create_language_vocabulary() {
  $description = st('The language categories.');
  $vocabulary = (object) array(
    'name' => st('Languages'),
    'description' => $description,
    'machine_name' => CULTURA_QUESTIONNAIRE_LANGUAGE_VOCABULARY,
  );
  taxonomy_vocabulary_save($vocabulary);
  return $vocabulary;
}
